#!/bin/sh -v

set -e

aclocal
autoheader
touch stamp-h
autoconf
libtoolize --copy --force --automake
automake -a -c
glib-gettextize --copy --force
intltoolize --automake --copy --force
